@@ -11,10 +11,14 @@ class ExceptionThrowed(Dispatchable):
     exception: Exception
     event: Dispatchable
 
+    def __init__(self, exception: Exception, event: Dispatchable) -> None:
+        self.exception = exception
+        self.event = event
+
     class Dispatcher(BaseDispatcher):
         @staticmethod
         def catch(interface: "DispatcherInterface"):
-            if interface.annotation == interface.event.exception.__class__:
-                return interface.event.exception
+            if interface.annotation == interface.event.exception.__class__:  # type: ignore
+                return interface.event.exception  # type: ignore
             if interface.name == "event":
-                return interface.event.event
+                return interface.event.event  # type: ignore
