@@ -1,4 +1,4 @@
-import itertools
+from itertools import chain
 from functools import lru_cache
 from typing import (
     TYPE_CHECKING,
@@ -44,12 +44,9 @@ T_Event = TypeVar("T_Event", bound=Dispatchable)
 
 
 LIFECYCLE_ABS = {
-    BaseDispatcher.beforeDispatch,
     BaseDispatcher.beforeExecution,
-    BaseDispatcher.beforeTargetExec,
     BaseDispatcher.afterDispatch,
     BaseDispatcher.afterExecution,
-    BaseDispatcher.afterTargetExec,
 }
 
 
@@ -66,7 +63,7 @@ class DispatcherInterface(Generic[T_Event]):
         return self.track_logs[-1]
 
     def dispatcher_pure_generator(self) -> Iterable[T_Dispatcher]:
-        return itertools.chain(
+        return chain(
             self.execution_contexts[0].dispatchers,
             self.parameter_contexts[-1].dispatchers,
             self.execution_contexts[-1].dispatchers,
@@ -93,7 +90,7 @@ class DispatcherInterface(Generic[T_Event]):
         if dispatchers is None and lifecycle_refs != LF_TEMPLATE:
             return
 
-        for dispatcher in dispatchers or itertools.chain(
+        for dispatcher in dispatchers or chain(
             self.execution_contexts[0].dispatchers,
             self.parameter_contexts[-1].dispatchers,
             self.execution_contexts[-1].dispatchers,
